[Koha-cvs] koha/opac opac-serial-issues.pl opac-suggestion...

Antoine Farnault antoine at koha-fr.org
Fri Jul 7 11:01:03 CEST 2006


CVSROOT:	/sources/koha
Module name:	koha
Changes by:	Antoine Farnault <toins>	06/07/07 09:01:03

Modified files:
	opac           : opac-serial-issues.pl opac-suggestions.pl 

Log message:
	Sub renamed & GPL Licence added.

CVSWeb URLs:
http://cvs.savannah.gnu.org/viewcvs/koha/opac/opac-serial-issues.pl?cvsroot=koha&r1=1.6&r2=1.7
http://cvs.savannah.gnu.org/viewcvs/koha/opac/opac-suggestions.pl?cvsroot=koha&r1=1.5&r2=1.6

Patches:
Index: opac-serial-issues.pl
===================================================================
RCS file: /sources/koha/koha/opac/opac-serial-issues.pl,v
retrieving revision 1.6
retrieving revision 1.7
diff -u -b -r1.6 -r1.7
--- opac-serial-issues.pl	21 May 2006 02:29:09 -0000	1.6
+++ opac-serial-issues.pl	7 Jul 2006 09:01:03 -0000	1.7
@@ -1,11 +1,30 @@
 #!/usr/bin/perl
 
+# Copyright 2000-2002 Katipo Communications
+#
+# This file is part of Koha.
+#
+# Koha is free software; you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software
+# Foundation; either version 2 of the License, or (at your option) any later
+# version.
+#
+# Koha is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# Koha; if not, write to the Free Software Foundation, Inc., 59 Temple Place,
+# Suite 330, Boston, MA  02111-1307 USA
+
+# $Id: opac-serial-issues.pl,v 1.7 2006/07/07 09:01:03 toins Exp $
+
 use strict;
 use CGI;
 use C4::Auth;
 use C4::Koha;
 use C4::Date;
-use C4::Bull;
+use C4::Serials;
 use C4::Letters;
 use C4::Output;
 use C4::Interface::CGI::Output;
@@ -23,7 +42,7 @@
 my ($template, $loggedinuser, $cookie);
 my $biblionumber = $query->param('biblionumber');
 if ($selectview eq "full"){
-	my $subscriptions = get_full_subscription_list_from_biblionumber($biblionumber);
+	my $subscriptions = GetFullSubscriptionListFromBiblionumber($biblionumber);
 	
 	my $title = $subscriptions->[0]{bibliotitle};
 	my $yearmin=$subscriptions->[0]{year};
@@ -51,7 +70,7 @@
 		);
 
 } else {
-	my $subscriptions = get_subscription_list_from_biblionumber($biblionumber);
+	my $subscriptions = GetSubscriptionListFromBiblionumber($biblionumber);
 	
 	($template, $loggedinuser, $cookie)
 	= get_template_and_user({template_name => "opac-serial-issues.tmpl",

Index: opac-suggestions.pl
===================================================================
RCS file: /sources/koha/koha/opac/opac-suggestions.pl,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -b -r1.5 -r1.6
--- opac-suggestions.pl	4 Jul 2006 14:36:52 -0000	1.5
+++ opac-suggestions.pl	7 Jul 2006 09:01:03 -0000	1.6
@@ -47,8 +47,8 @@
 }
 
 if ($op eq "add_confirm") {
-	&newsuggestion($borrowernumber,$title,$author,$publishercode,$note,$copyrightdate,$volumedesc,$publicationyear,$place,$isbn,'');
-	# empty fields, to avoid filter in "searchsuggestion"
+	&NewSuggestion($borrowernumber,$title,$author,$publishercode,$note,$copyrightdate,$volumedesc,$publicationyear,$place,$isbn,'');
+	# empty fields, to avoid filter in "SearchSuggestion"
 	$title='';
 	$author='';
 	$publishercode='';
@@ -63,12 +63,12 @@
 if ($op eq "delete_confirm") {
 	my @delete_field = $input->param("delete_field");
 	foreach my $delete_field (@delete_field) {
-		&delsuggestion($borrowernumber,$delete_field);
+		&DelSuggestion($borrowernumber,$delete_field);
 	}
 	$op='else';
 }
 
-my $suggestions_loop= &searchsuggestion($borrowernumber,$author,$title,$publishercode,$status,$suggestedbyme);
+my $suggestions_loop= &SearchSuggestion($borrowernumber,$author,$title,$publishercode,$status,$suggestedbyme);
 $template->param(suggestions_loop => $suggestions_loop,
 				title => $title,
 				author => $author,





More information about the Koha-cvs mailing list